pub struct SessionActivityEvent {
pub event_type: String,
pub payload: Option<Value>,
pub timestamp: DateTime<Utc>,
}Expand description
A durable session activity event captured for replay and export.
Fields
event_type: StringStable event discriminant (for example, agent-stream-chunk).
payload: Option<Value>Optional JSON payload captured at the time of emission.
timestamp: DateTime<Utc>Timestamp in UTC.
Implementations
Sourceimpl SessionActivityEvent
impl SessionActivityEvent
Sourcepub fn new(
event_type: impl Into<String>,
payload: Option<Value>,
) -> SessionActivityEvent
pub fn new( event_type: impl Into<String>, payload: Option<Value>, ) -> SessionActivityEvent
Create a new activity event stamped with the current time.
Sourcepub fn with_timestamp(
event_type: impl Into<String>,
payload: Option<Value>,
timestamp: DateTime<Utc>,
) -> SessionActivityEvent
pub fn with_timestamp( event_type: impl Into<String>, payload: Option<Value>, timestamp: DateTime<Utc>, ) -> SessionActivityEvent
Create a new activity event with an explicit timestamp.